@@ -1,13 +1,12 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Tuple, Any
+from typing import TYPE_CHECKING, Any, Tuple
 
 from starlette.responses import JSONResponse
 
 if TYPE_CHECKING:
-    from starlette.requests import Request
-
     from pydantic import BaseModel
+    from starlette.requests import Request
 
     from ...aio.client import AsyncClient
     from ..app import AutumnIdentifyData
@@ -28,4 +27,4 @@ async def _extract(
 
 
 def _build_response(response: BaseModel) -> JSONResponse:
-    return JSONResponse(response.model_dump(mode="json"))
\ No newline at end of file
+    return JSONResponse(response.model_dump(mode="json"))
