@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from . import _extract, _build_response
+from . import _build_response, _extract
 
 if TYPE_CHECKING:
     from starlette.requests import Request
@@ -12,7 +12,7 @@ async def create_entity_route(request: Request):
     _, autumn, json = await _extract(request)
 
     customer_id = request.path_params["customer_id"]
-    response = await autumn.features.create_entity(customer_id=customer_id, **json)
+    response = await autumn.entities.create(customer_id=customer_id, **json)
 
     return _build_response(response)
 
@@ -22,7 +22,7 @@ async def delete_entity_route(request: Request):
 
     customer_id = request.path_params["customer_id"]
     entity_id = request.path_params["entity_id"]
-    response = await autumn.features.delete_entity(customer_id, entity_id)
+    response = await autumn.entities.delete(customer_id, entity_id)
 
     return _build_response(response)
 
@@ -37,5 +37,5 @@ async def get_entity_route(request: Request):
     if expand is not None:
         expand = expand.split(",")
 
-    response = await autumn.features.get_entity(customer_id, entity_id, expand)
+    response = await autumn.entities.get(customer_id, entity_id, expand)
     return _build_response(response)
